pg = require 'pg'

Store = require '../../src/store/postgres'

module.exports =
    setUp: (next) ->
        env = this
        env.connections = []
        getConnection = (cb) ->
            client = new pg.Client process.env.PSQL
            client.connect()
            env.connections.push client
            cb null, client
        env.store = Store getConnection
        getConnection (err, client) ->
            throw err if err?
            client.query 'DELETE FROM session;', (err) ->
            next()

    tearDown: (next) ->
        env = this
        env.connections.forEach (connection) ->
            connection.end()
        env.connections = []
        next()

    'retrieve empty values if id does not exist': (test) ->
        @store.get 'does not exist', (err, result) ->
            test.deepEqual {}, result
            test.done()

    'set and get values': (test) ->
        store = @store
        store.set 'id', {foo: 'bar'}, (err) ->
            test.ifError err
            store.get 'id', (err, result) ->
                test.ifError err
                test.equal 'bar', result.foo
                test.done()

    'update works': (test) ->
        store = @store
        store.set 'foo', {x: 1}, (err) ->
            test.ifError err
            store.set 'foo', {x: 2}, (err) ->
                test.ifError err
                store.get 'foo', (err, result) ->
                    test.ifError err
                    test.equal 2, result.x
                    test.done()

    'test delete older': (test) ->
        store = @store
        store.set 'foo', {x: 1}, (err) ->
            throw err if err?
            store.deleteOlderThen new Date(), (err) ->
                throw err if err?
                store.get 'foo', (err, session) ->
                    throw err if err?
                    test.deepEqual {}, session
                    test.done()
